@@ -1,4 +1,18 @@
 
+#####################################################################
+#
+# s_db.py
+#
+# Project   : OMNICLIENT
+# Author(s) : Zafar Iqbal < zaf@sparc.space >
+# Copyright : (C) 2021 SPARC PC < https://sparc.space/ >
+#
+# All rights reserved. No warranty, explicit or implicit, provided.
+# SPARC PC is and remains the owner of all titles, rights
+# and interests in the Software.
+#
+#####################################################################
+
 import os
 import json
 import hashlib
@@ -236,6 +250,39 @@ def meta_get( mn ) :
 
     return(False)
 
+
+def meta_add_asjson( mn , mv_data ) :
+    con = sqlite3.connect( db_filepath )
+    cur = con.cursor( )
+
+    mv = s_util.json_encode(mv_data)
+    cur.execute( "INSERT INTO meta VALUES ( '" + mn + "' , '" + mv + "' , null )" )
+
+    
+    con.commit( )
+    con.close( )
+    return(True)
+
+def meta_get_jsondecoded( mn ) :
+    con = sqlite3.connect( db_filepath )
+    cur = con.cursor( )
+
+    #cur.execute( "INSERT INTO meta VALUES ( null , " + str( dk ) + " , '" + dv + "' )" )
+    cur.execute( "SELECT mvs FROM meta where mn='" + mn + "' " )
+    rows = cur.fetchall( )
+    con.close( )
+    #s_log.write( rows )
+
+    if( len( rows ) != 1 ) : return( False )
+    #s_log.write( rows )
+
+    meta_data = json.loads(rows[0][0])
+
+    #if( rows[ 0 ][ 0 ] == None ) : return( rows[ 0 ][ 1 ] )
+    #if( rows[ 0 ][ 1 ] == None ) : return( rows[ 0 ][ 0 ] )
+
+    return(meta_data)
+
 ####################################################################
 
 def args_add( av ) :
